@@ -39,6 +39,8 @@ class Form(QScrollArea):
     self.messageEdt.setEnabled(self.enabledBtn.isChecked())
     self.vbox.addWidget(self.messageEdt)
 
+    QObject.connect(self.messageEdt, SIGNAL('textEdited(const QString &)'), self.update_template)
+
     QObject.connect(self.enabledBtn, SIGNAL('toggled(bool)'),
                     lambda v: self.__config.set_enabled(self.current_profile, v, False))
 
@@ -111,6 +113,10 @@ class Form(QScrollArea):
       else:
         accounts.remove(account)
 
+  def update_template(self, text):
+    if not self.__updating:
+      self.__config.set_template(self.current_profile, str(text), False)
+
 class MediaSelector(QWidget):
   def __init__(self, controller):
     QWidget.__init__(self)
